==> hangthepyman-0.1.2.tar.gz: hangthepyman-0.1.2/README.md <==
# HangThePyMan

> Classic Hangman game with Pygame & Python touch.

![Python Version][pypi-image]
![Build Status][pypi-status]
[![Downloads Stats][pypi-version]][pypi-url]

Implementation of the hangman game in Pygame. With the ability to ask today's word, most used & searched words and bunch of other fun options to play.

![screen1](screenshots/screen1.png)

## Table of Contents

* [Installation](#Installation)
* [TODO's](#TODO's)
* [Release History](#Release-History)
* [Meta](#Meta)
* [Contributing](#Contributing)

## Installation

Pip:

```sh
pip install hangthepyman
```

after that you can run this on your command line:

```sh
python -m hangthepyman
```

Source:

After cloning, head to hangthepyman directory and run:

```sh
python3 the_hangman.py
```

## TODO's

* Add Menu
* Add Music
* ~~Complete word functions to improve asked words~~ and add hint option

## Release History

* 0.1.2
  * Refactored path codes. There shouldn't be any path problems anymore.
  Tested on Kali Linux and Win10. Hopefully works on these platforms. If you encounter any problems make sure you have pygame installed.
* 0.1.1
  * Added Random word function. (You now have 20k words to guess!)
  * Now shows what was the word if u happen to lose or win.
  * Fixed path issues.
* 0.0.2
  * Fixed path issue
* 0.0.1
  * Created the game :)

## Meta

Berkay Girgin – [@Gerile3](https://github.com/Gerile3) – berkay.grgn@protonmail.com

Distributed under the MIT license. See ``LICENSE`` for more information.

## Contributing

1. Fork it (<https://github.com/Gerile3/HangThePyMan/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request

<!-- Markdown link & img dfn's -->
[pypi-image]: https://img.shields.io/pypi/pyversions/hangthepyman
[pypi-url]: https://pypi.org/project/hangthepyman/
[pypi-version]: https://img.shields.io/pypi/v/hangthepyman
[pypi-status]: https://img.shields.io/pypi/status/hangthepyman

==> hangthepyman-0.1.3.tar.gz: hangthepyman-0.1.3/README.md <==
# HangThePyMan

> Classic Hangman game with Pygame & Python touch.

![Python Version][pypi-image]
![Build Status][pypi-status]
[![Downloads Stats][pypi-version]][pypi-url]

Implementation of the hangman game in Pygame. With the ability to ask today's word, most used & searched words and bunch of other fun options to play.

![screen1](screenshots/screen1.png)

## Table of Contents

* [Installation](#Installation)
* [TODO's](#TODO's)
* [Release History](#Release-History)
* [Meta](#Meta)
* [Contributing](#Contributing)

## Installation

Pip:

```sh
pip install hangthepyman
```

after that you can run this on your command line:

```sh
python -m hangthepyman
```

Source:

After cloning, head to hangthepyman directory and run:

```sh
python3 the_hangman.py
```

## TODO's

* ~~Add Menu~~
* Add Music
* ~~Complete word functions to improve asked words~~ and add Hint option

## Release History

* 0.1.3
  * fixed directory passings to support python 3.6+
  * Added Main Menu
  * Added End Game Screen, you can continue to play now if you wish so.
* 0.1.2
  * Refactored path codes. There shouldn't be any path problems anymore.
  Tested on Kali Linux and Win10. Hopefully works on these platforms. If you encounter any problems make sure you have pygame installed.
* 0.1.1
  * Added Random word function. (You now have 20k words to guess!)
  * Now shows what was the word if u happen to lose or win.
  * Fixed path issues.
* 0.0.2
  * Fixed path issue
* 0.0.1
  * Created the game :)

## Meta

Berkay Girgin – [@Gerile3](https://github.com/Gerile3) – berkay.grgn@protonmail.com

Distributed under the MIT license. See ``LICENSE`` for more information.

## Contributing

1. Fork it (<https://github.com/Gerile3/HangThePyMan/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request

<!-- Markdown link & img dfn's -->
[pypi-image]: https://img.shields.io/pypi/pyversions/hangthepyman
[pypi-url]: https://pypi.org/project/hangthepyman/
[pypi-version]: https://img.shields.io/pypi/v/hangthepyman
[pypi-status]: https://img.shields.io/pypi/status/hangthepyman
